essentieel-4

Schrijf zelf de `INSERT`-instructie om volgende kunstwerken toe te voegen aan de tabel uit de vorige oefening:

- Het kunstwerk Guernica van Pablo Picasso, met een waarde van 2 miljoen.
- Het kunstwerk De Denker van Auguste Rodin, met een waarde van 1 miljoen.
- Het kunstwerk Mona Lisa van Leonardo Da Vinci, met een waarde van 2 miljoen.

Voer je code uit wanneer je klaar bent om ze te testen. Controleer de output van je script. Indien de instructie mis loopt, lees dan de foutmelding en probeer het probleem op te lossen. Sla je uiteindelijke script op onder MySQL/Essentieel/InsertKunstwerken.sql.